
import json
import smtplib

from typing import List

from airless.core.hook import EmailHook
from airless.core.utils import get_config

secret_locations = f'/secrets/{get_config("SECRET_SMTP")}'
with open(secret_locations) as f:
    SECRET = json.loads(f.read())


class GoogleEmailHook(EmailHook):
    """Hook for sending emails using Google Email service."""

    def __init__(self) -> None:
        """Initializes the GoogleEmailHook."""
        super().__init__()

    def send(self, subject: str, content: str, recipients: List[str], sender: str, attachments: List[dict], mime_type: str) -> None:
        """Sends an email.

        Args:
            subject (str): The subject of the email.
            content (str): The content of the email.
            recipients (List[str]): The list of email recipients.
            sender (str): The sender's email address.
            attachments (List[dict]): The list of attachments.
            mime_type (str): The MIME type of the email content.
        """
        msg = self.build_message(subject, content, recipients, sender, attachments, mime_type)
        server = smtplib.SMTP_SSL(SECRET['host'], SECRET['port'])

        try:
            server.login(SECRET['user'], SECRET['password'])
            server.sendmail(sender, recipients, msg.as_string())
        finally:
            server.close()




from typing import List

from airless.google.cloud.core.operator import GoogleBaseEventOperator

from airless.google.cloud.storage.hook import GcsHook
from airless.email.hook import GoogleEmailHook


class GoogleEmailSendOperator(GoogleBaseEventOperator):
    """Operator for sending emails using Google Email Hook."""

    def __init__(self) -> None:
        """Initializes the GoogleEmailSendOperator."""
        super().__init__()
        self.email_hook = GoogleEmailHook()
        self.gcs_hook = GcsHook()

    def execute(self, data: dict, topic: str) -> None:
        """Executes the email sending process.

        Args:
            data (dict): The data containing email information.
            topic (str): The Pub/Sub topic.
        """
        subject: str = data['subject']
        content: str = data['content']
        recipients: List[str] = data['recipients']
        sender: str = data.get('sender', 'Airless notification')
        attachments: List[dict] = data.get('attachments', [])
        mime_type: str = data.get('mime_type', 'plain')

        attachment_contents: List[dict] = []
        for att in attachments:
            attachment_contents.append({
                'type': att.get('type', 'text'),
                'content': self.gcs_hook.read_as_string(att['bucket'], att['filepath'], att['encoding'])
            })

        self.email_hook.send(subject, content, recipients, sender, attachment_contents, mime_type)
